import type { Command } from 'commantor'
import Logger from 'config/logger'
import fs from 'node:fs/promises'
import path from 'node:path/posix'

const command: Command = {
	name: 'migrations:load',
	description: 'Load the list of migrations into the app',
	async run() {
		const source = './src/models/migrations'
		const target = './src/models/migrations/list.ts'
		const targetFolder = './src/models/migrations'
		const relative = path.relative(source, targetFolder)
		const migrations = (await fs.readdir(source))
			.filter((it) => !it.endsWith('.d.ts') && it.startsWith('Migration'))
			.map((it) => ({
				path: './' + relative + it,
				name: it.replace(/-/g, '').replace('.ts', '')
			}))
			.sort((a, b) => a.name > b.name ? 1 : -1)
		const importStr = (it: { path: string, name: string }) => `import ${it.name} from '${it.path}'`
		const file = `${migrations.map(importStr).join('\n')}

/**
 * DO NOT EDIT MANUALLY
 * Auto generated file from the command "./cmd.ts migrations:load"
 */

export default [
${migrations.map((it) => `	${it.name}`).join(',\n')}
]
`
		await fs.writeFile(target, file)
		Logger.info('loaded migrations into', target)
		return {
			code: 0
		}
	},
}
export default command
