import { getSecret } from 'astro:env/server'
import type { environmentVariables } from 'config/envs'

/**
 * Get the environment variable
 *
 * @param key the env variable key
 * @param defaultValue a default value if applicable
 * @returns the environment value or undefined if not found
 */
export function getEnv(key: environmentVariables, defaultValue: string): string
export function getEnv(key: environmentVariables, defaultValue?: string): string | undefined
export function getEnv(key: environmentVariables, defaultValue?: string): string | undefined {
	// get the env variable through Astro > NodeJS > input
	// eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
	const res = getSecret(key) ?? import.meta.env[key] ?? process.env[key] ?? defaultValue

	// eslint-disable-next-line @typescript-eslint/no-unsafe-return
	return res ?? undefined
}

/**
 * get the environment variable and throws if not found
 *
 * @throws {Error} if the env variable is not found
 * @param key the env variable key
 * @param defaultValue a default value if applicable
 * @returns the environment value
 */
export function requireEnv(key: environmentVariables, defaultValue?: string): string {
	// get the env variable through Astro > NodeJS > input
	const res = getEnv(key, defaultValue)

	// throw if env variable is not set
	if (!res) {
		throw new Error(`MissingEnvError: the env ${key} is not set!`)
	}
	return res
}

export function envExists(key: environmentVariables): boolean {
	return !!getEnv(key)
}
